API reference
=============


xemc3 Dataset
-----------------

.. automodule:: xemc3.EMC3DatasetAccessor


xemc3.load module
-----------------

.. automodule:: xemc3.load


xemc3.write module
------------------

.. automodule:: xemc3.write.fortran
.. automodule:: xemc3.write.nc
